package com.fs.erp.http;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.fs.erp.dto.*;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.stereotype.Service;


@Service
public class JstErpHttpServiceImpl implements JstErpHttpService{

    private static final String BASE_URL = "https://openapi.jushuitan.com/";
    /**
     * 获取access_token、refresh_token url
     */
    private static final String GET_INIT_TOKEN_URL = BASE_URL+"openWeb/auth/getInitToken";

    /**
     * 更新access_token、refresh_token url
     */
    private static final String REFRESH_TOKEN_URL = BASE_URL+"openWeb/auth/refreshToken";


    @Override
    public GetInitTokenResponseDTO getInitToken(GetInitTokenRequestDTO dto) {
        String post = HttpUtil.post(GET_INIT_TOKEN_URL, JSON.toJSONString(dto));

        TypeReference<CommonResponse<GetInitTokenResponseDTO>> typeReference = new TypeReference<CommonResponse<GetInitTokenResponseDTO>>(){};
        CommonResponse<GetInitTokenResponseDTO> response = JSON.parseObject(post, typeReference);
        if(ObjectUtils.notEqual(response.getCode(),0)) {
            throw new RuntimeException("请求接口失败！原因："+response.getMsg());
        }
        return response.getData();
    }

    @Override
    public GetInitTokenResponseDTO refreshToken(GetInitTokenRequestDTO dto) {
        String post = HttpUtil.post(REFRESH_TOKEN_URL, JSON.toJSONString(dto));
        TypeReference<CommonResponse<GetInitTokenResponseDTO>> typeReference = new TypeReference<CommonResponse<GetInitTokenResponseDTO>>(){};
        CommonResponse<GetInitTokenResponseDTO> response = JSON.parseObject(post, typeReference);
        if(ObjectUtils.notEqual(response.getCode(),0)) {
            throw new RuntimeException("请求接口失败！原因："+response.getMsg());
        }
        return response.getData();
    }

    @Override
    public ProductUploadResultDTO uploadGoods(GoodsInfoDTO dto) {

        String post = HttpUtil.post(BASE_URL + "/open/jushuitan/itemsku/upload", JSON.toJSONString(dto));
        TypeReference<CommonResponse<ProductUploadResultDTO>> typeReference = new TypeReference<CommonResponse<ProductUploadResultDTO>>(){};
        CommonResponse<ProductUploadResultDTO> response = JSON.parseObject(post, typeReference);
        if(ObjectUtils.notEqual(response.getCode(),0)) {
            throw new RuntimeException("请求接口失败！原因："+response.getMsg());
        }
        return response.getData();
    }

    @Override
    public ProductResponseDTO queryGoods(ProductQueryRequestDTO dto) {
        String post = HttpUtil.post(BASE_URL + "/open/sku/query", JSON.toJSONString(dto));
        TypeReference<CommonResponse<ProductResponseDTO>> typeReference = new TypeReference<CommonResponse<ProductResponseDTO>>(){};
        CommonResponse<ProductResponseDTO> response = JSON.parseObject(post, typeReference);
        if(ObjectUtils.notEqual(response.getCode(),0)) {
            throw new RuntimeException("请求接口失败！原因："+response.getMsg());
        }
        return response.getData();
    }
}
